==> safe-request-scanner-0.0.2-alpha.tgz: package/src/detectors/sqlInjectionDetector.ts <==
const reservedWords = [
  'SELECT',
  'UPDATE',
  'DELETE',
  'INSERT',
  'DROP',
  'UNION',
  'AND',
  'OR',
  'WHERE',
  'FROM',
  'JOIN',
  'TABLE',
  'INTO',
  'VALUES',
  'SET',
  'CREATE',
  'ALTER',
  'INDEX',
  'VIEW',
  'TRIGGER',
  'PROCEDURE',
  'FUNCTION',
  'DATABASE',
  'COLUMN',
  'KEY',
  'PRIMARY',
  'FOREIGN',
  'REFERENCES',
  'GROUP',
  'ORDER',
  'BY',
  'HAVING',
  'LIMIT',
  'OFFSET',
];

export function isSQLSentence(input: string): boolean {
  const upperInput = input.toUpperCase().trim();

  // Detectar si contiene más de una palabra reservada
  const words = upperInput.split(/\s+/);
  const reservedWordCount = words.filter((word) =>
    reservedWords.includes(word),
  ).length;

  if (reservedWordCount > 1) {
    return true; // Es una sentencia SQL si contiene más de una palabra reservada
  }

  // Detectar patrones comunes de sentencias SQL
  const sqlPatterns = [
    /\bSELECT\b.*\bFROM\b/,
    /\bINSERT\b.*\bINTO\b/,
    /\bUPDATE\b.*\bSET\b/,
    /\bDELETE\b.*\bFROM\b/,
    /\bCREATE\b.*\bTABLE\b/,
    /\bDROP\b.*\bTABLE\b/,
    /\bALTER\b.*\bTABLE\b/,
    /\bUNION\b.*\bSELECT\b/,
    /\bJOIN\b.*\bON\b/,
    /\bCREATE\b.*\bDATABASE\b/,
    /\bCREATE\b.*\bVIEW\b/,
    /\bCREATE\b.*\bINDEX\b/,
    /\bCREATE\b.*\bTRIGGER\b/,
    /\bCREATE\b.*\bPROCEDURE\b/,
    /\bCREATE\b.*\bFUNCTION\b/,
    /\bALTER\b.*\bDATABASE\b/,
    /\bALTER\b.*\bVIEW\b/,
    /\bALTER\b.*\bINDEX\b/,
    /\bALTER\b.*\bTRIGGER\b/,
    /\bALTER\b.*\bPROCEDURE\b/,
    /\bALTER\b.*\bFUNCTION\b/,
    /\bDROP\b.*\bDATABASE\b/,
    /\bDROP\b.*\bVIEW\b/,
    /\bDROP\b.*\bINDEX\b/,
    /\bDROP\b.*\bTRIGGER\b/,
    /\bDROP\b.*\bPROCEDURE\b/,
    /\bDROP\b.*\bFUNCTION\b/,
  ];

  for (const pattern of sqlPatterns) {
    if (pattern.test(upperInput)) {
      return true; // Es una sentencia SQL si coincide con algún patrón
    }
  }

  return false; // No es una sentencia SQL si no cumple con los criterios anteriores
}

export function detectSQLInjection(input: string): boolean {
  const sqlInjectionPattern =
    /(\b(SELECT|UPDATE|DELETE|INSERT|DROP|UNION|AND|OR|--)|\b\d{2,}\b|(['"];\s*--))/i;
  return sqlInjectionPattern.test(input);
}

==> safe-request-scanner-0.0.7-alpha.tgz: package/src/detectors/sqlInjectionDetector.ts <==
const RESERVED_WORDS = [
  'SELECT',
  'UPDATE',
  'DELETE',
  'INSERT',
  'DROP',
  'UNION',
  'AND',
  'OR',
  'WHERE',
  'FROM',
  'JOIN',
  'TABLE',
  'INTO',
  'VALUES',
  'SET',
  'CREATE',
  'ALTER',
  'INDEX',
  'VIEW',
  'TRIGGER',
  'PROCEDURE',
  'FUNCTION',
  'DATABASE',
  'COLUMN',
  'KEY',
  'PRIMARY',
  'FOREIGN',
  'REFERENCES',
  'GROUP',
  'ORDER',
  'BY',
  'HAVING',
  'LIMIT',
  'OFFSET',
];

export function isSQLSentence(input: string): boolean {
  const UPPER_INPUT = input.toUpperCase().trim();

  // Detectar si contiene más de una palabra reservada
  const WORDS = UPPER_INPUT.split(/\s+/);
  const RESERVED_WORD_COUNT = WORDS.filter((word) =>
    RESERVED_WORDS.includes(word),
  ).length;

  if (RESERVED_WORD_COUNT > 1) {
    return true; // Es una sentencia SQL si contiene más de una palabra reservada
  }

  // Detectar patrones comunes de sentencias SQL
  const SQL_PATTERNS = [
    /\bSELECT\b.*\bFROM\b/,
    /\bINSERT\b.*\bINTO\b/,
    /\bUPDATE\b.*\bSET\b/,
    /\bDELETE\b.*\bFROM\b/,
    /\bCREATE\b.*\bTABLE\b/,
    /\bDROP\b.*\bTABLE\b/,
    /\bALTER\b.*\bTABLE\b/,
    /\bUNION\b.*\bSELECT\b/,
    /\bJOIN\b.*\bON\b/,
    /\bCREATE\b.*\bDATABASE\b/,
    /\bCREATE\b.*\bVIEW\b/,
    /\bCREATE\b.*\bINDEX\b/,
    /\bCREATE\b.*\bTRIGGER\b/,
    /\bCREATE\b.*\bPROCEDURE\b/,
    /\bCREATE\b.*\bFUNCTION\b/,
    /\bALTER\b.*\bDATABASE\b/,
    /\bALTER\b.*\bVIEW\b/,
    /\bALTER\b.*\bINDEX\b/,
    /\bALTER\b.*\bTRIGGER\b/,
    /\bALTER\b.*\bPROCEDURE\b/,
    /\bALTER\b.*\bFUNCTION\b/,
    /\bDROP\b.*\bDATABASE\b/,
    /\bDROP\b.*\bVIEW\b/,
    /\bDROP\b.*\bINDEX\b/,
    /\bDROP\b.*\bTRIGGER\b/,
    /\bDROP\b.*\bPROCEDURE\b/,
    /\bDROP\b.*\bFUNCTION\b/,
  ];

  for (const pattern of SQL_PATTERNS) {
    if (pattern.test(UPPER_INPUT)) {
      return true; // Es una sentencia SQL si coincide con algún patrón
    }
  }

  return false; // No es una sentencia SQL si no cumple con los criterios anteriores
}

export function detectSQLInjection(input: string): boolean {
  const SQL_INJECTION_PATTERN =
    /(\b(SELECT|UPDATE|DELETE|INSERT|DROP|UNION|AND|OR|--)|\b\d{2,}\b|(['"];\s*--))/i;
  return SQL_INJECTION_PATTERN.test(input);
}
